@@ -1,6 +1,6 @@
 import abc
 from enum import Enum
-from typing import Any
+from typing import Any, Union
 
 from hcube.api.models.dimensions import Dimension
 
@@ -10,6 +10,12 @@ class Filter(abc.ABC):
         self.dimension = dimension
 
 
+class EqualityFilter(Filter):
+    def __init__(self, dimension: Dimension, value: Union[str, int]):
+        super().__init__(dimension)
+        self.value = value
+
+
 class ListFilter(Filter):
     def __init__(self, dimension: Dimension, values: list):
         super().__init__(dimension)
